@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Scalar::Util qw/reftype/;
 use Carp qw/croak/;
@@ -90,7 +90,7 @@ Blessed::Merge - Merge Blessed Refs.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
@@ -119,7 +119,7 @@ Instantiate a new Blessed::Merge object.
 Setting unique_hash will only set undefined key/values in the hash.
 
 	use JSONP;
-	use overlord::x qw/n/;
+	use overload::x qw/n/;
 
 	my $blessed = Blessed::Merge->new({ unique_hash => 1 });
 	
@@ -150,7 +150,7 @@ Setting unique_hash will only set undefined key/values in the hash.
 Setting unique_array will merge arrays based on order and unique value.
 
 	use JSONP;
-	use overlord::x qw/n/;
+	use overload::x qw/n/;
 
 	my $blessed = Blessed::Merge->new({ unique_array => 1 });
 	
@@ -169,7 +169,7 @@ Setting unique_array will merge arrays based on order and unique value.
 Disable to return the non blessed ref.
 
 	use JSONP;
-	use overlord::x qw/n/;
+	use overload::x qw/n/;
 
 	my $blessed = Blessed::Merge->new({ blessed => 1 });
 
